###############
import nengolib
###############

Additional extensions and tools for modelling dynamical systems in
`Nengo <https://github.com/nengo/nengo>`_.

.. toctree::
   :maxdepth: 2

   notebooks
   reference
   success
   license

************
Installation
************

`Nengolib <https://github.com/arvoelke/nengolib/>`_
is tested against Python 2.7, 3.4, 3.5, and 3.6, and `Nengo`_
2.2.0, 2.3.0, 2.4.0, 2.5.0, 2.6.0, 2,7.0, and 2.8.0.
We recommend ``nengo==2.8.0`` for complete access to features.
We do not currently support ``nengo>=3.0``.
The `Nengo GUI <https://github.com/nengo/nengo_gui>`_ is not officially
supported.
To install::

    pip install nengolib

This requires
`nengo>=2.2.0,<3.0 <https://github.com/nengo/nengo/releases/tag/v2.2.0>`_
`numpy>=1.13 <https://github.com/numpy/numpy/releases/tag/v1.13.0>`_, and
`scipy>=0.19.0 <https://github.com/scipy/scipy/releases/tag/v0.19.0>`_.
If you are having difficulty installing SciPy or NumPy, we recommend the
`Anaconda <https://www.continuum.io/downloads>`_ installer.

:ref:`genindex`
===============
